// eslint-disable-next-line @typescript-eslint/ban-ts-comment
// @ts-nocheck
import puppeteer from 'puppeteer'
const BASE_URL = process.env.BASE_URL || 'https://git.nin0.dev'

const browser = await puppeteer.launch({
	defaultViewport: {
		width: 1200,
		height: 600
	},
	headless: true,
	// slowMo: 250,
	args: [
		// TODO: fix this
		'--disable-gpu',
		'--disable-dev-shm-usage',
		'--disable-setuid-sandbox',
		'--no-sandbox'
	]
})

async function wait() {
	// eslint-disable-next-line no-undef
	const selectors = [...document.querySelectorAll('img')]
	await Promise.all([
		// eslint-disable-next-line no-undef
		document.fonts.ready,
		...selectors.map(img => {
			// Image has already finished loading, let’s see if it worked
			if (img.complete) {
				// Image loaded and has presence
				if (img.naturalHeight !== 0) return
				// Image failed, so it has no height
				throw new Error('Image failed to load')
			}
			// Image hasn’t loaded yet, added an event listener to know when it does
			return new Promise((resolve, reject) => {
				img.addEventListener('load', resolve)
				img.addEventListener('error', reject)
			})
		})
	])
}

export async function renderPage(html: string) {
	const page = await browser.newPage()
	try {
		await page.setContent(html, {
			waitUntil: 'domcontentloaded'
		})
		await page.evaluate(wait)
		const buffer = await page.screenshot({
			type: 'png',
			encoding: 'binary'
		})
		page.close()
		return buffer
	} catch {
		await page.close()
		throw new Error('Failed to render page')
	}
}

export default async function (
	html: string,
	options: { format?: 'html' } = {}
) {
	const fullHtml = `<link rel="stylesheet" href="${BASE_URL}/assets/style.css">
		<link rel="stylesheet" href="${BASE_URL}/assets/DMSans/style.css">
		${html}`
	if (options.format == 'html') {
		return fullHtml
	}
	return await renderPage(fullHtml)
}
