import getLanguages from '$lib/getLanguages.js'
import { error } from '@sveltejs/kit'

export async function load({ params }) {
	let type = params.type
	if (!type.endsWith('s')) type += 's'
	if (params.type != 'issues' && params.type != 'pulls') {
		throw error(404, 'Invalid type')
	}

	const [issue, languages] = await Promise.all([
		fetch(
			`https://git.nin0.dev/api/v1/repos/${encodeURIComponent(params.owner)}/${encodeURIComponent(params.repo)}/issues/${encodeURIComponent(params.num)}`
		).then(response => response.json()),
		getLanguages(params.owner, params.repo)
	])
	const { user } = issue

	let commits
	if (issue.pull_request)
		commits = await fetch(
			`https://git.nin0.dev/api/v1/repos/${encodeURIComponent(params.owner)}/${encodeURIComponent(params.repo)}/pulls/${encodeURIComponent(params.num)}/commits`
		).then(response => response.json())

	let stats
	const files = new Set()
	if (commits) {
		stats ??= { total: 0, additions: 0, deletions: 0, files: 0 }
		for (const commit of commits) {
			stats.total += commit.stats.total
			stats.additions += commit.stats.additions
			stats.deletions += commit.stats.deletions
			for (const file of commit.files) {
				files.add(file.filename)
			}
		}
		stats.files = files.size
	}

	return {
		repo: {
			owner: {
				login: params.owner
			},
			name: params.repo
		},
		created_at: new Date(issue.created_at),
		issue,
		stats,
		author: user,
		icon: user.avatar_url,
		languages
	}
}
