import languagecolors from '$lib/languagecolors.js'

function prepareLanguageResults(languages: { [key: string]: number }) {
	let sum = 0
	const values = Object.values(languages)
	for (const value of values) {
		sum += value
	}
	return Object.keys(languages).map(language => {
		return {
			color: languagecolors[language],
			percentage: (languages[language] / sum) * 100
		}
	})
}

export async function load({ params }) {
	const [commitResponse, languages] = await Promise.all([
		fetch(
			`https://git.nin0.dev/api/v1/repos/${encodeURIComponent(params.owner)}/${encodeURIComponent(params.repo)}/git/commits/${encodeURIComponent(params.sha)}`
		).then(response => response.json()),
		fetch(
			`https://git.nin0.dev/api/v1/repos/${encodeURIComponent(params.owner)}/${encodeURIComponent(params.repo)}/languages`
		).then(response => response.json())
	])
	const { commit, author, stats } = commitResponse
	return {
		repo: {
			owner: {
				login: params.owner
			},
			name: params.repo
		},
		created_at: new Date(commit.committer.date),
		icon: author.avatar_url,
		commit,
		sha: params.sha,
		author,
		stats,
		languages: prepareLanguageResults(languages)
	}
}
